part of 'notification_cubit.dart';

abstract class NotificationState extends Equatable {
  @override
  List<Object> get props => [];
}

class NotificationInitial extends NotificationState {}

class NotificationFailure extends NotificationState {
  final String error;

  NotificationFailure(this.error);

  @override
  String toString() => 'ForgotPassFailure { error: $error }';
}

class NotificationSuccess extends NotificationState {
  final String message;

  NotificationSuccess(this.message);

  @override
  String toString() => 'ForgotPassSuccess { message: $message }';
}

class NotificationLoading extends NotificationState {
  @override
  String toString() => 'ForgotPassLoading';
}

class GetListNotificationEmpty extends NotificationState {
  @override
  String toString() {
    return 'GetListNotificationEmpty{}';
  }
}

class GetNotificationSuccess extends NotificationState {
  @override
  String toString() => 'GetCategorySuccess';
}

class ReadNotificationSuccess extends NotificationState {

  @override
  String toString() => 'ReadNotificationSuccess';
}
